@@ -5,7 +5,7 @@ import simplejson,sys
 from operator import itemgetter
 from inspect import getmembers, isfunction
 import traceback
-
+import colorama
 
 varsFile = 'confIcli.json'
 vars = None
@@ -64,12 +64,12 @@ def _queryAndPrint(q,fields=None,systemFields=True,nullFields=False):
 def option_q(args):
     if '-h' in args:
         help = f"""
-        {utils.CGREEN}-q "select..."{utils.CEND} query to execute. System Fields, such as LastModifiedDate, and null fields are not returned. 
-            {utils.CGREEN}-null{utils.CEND} - will print fields with null values
-            {utils.CGREEN}-system{utils.CEND} - will print the system fields
-            {utils.CGREEN}-all{utils.CEND} - will print both nulls and system fields
-            {utils.CGREEN}-fields "a:b:c:..."{utils.CEND} --> print in table format the specified fields.
-            {utils.CGREEN}-fields all{utils.CEND} --> print in table format"""
+        {utils.CYELLOW}-q "select..."{utils.CEND} query to execute. System Fields, such as LastModifiedDate, and null fields are not returned. 
+            {utils.CYELLOW}-null{utils.CEND} - will print fields with null values
+            {utils.CYELLOW}-system{utils.CEND} - will print the system fields
+            {utils.CYELLOW}-all{utils.CEND} - will print both nulls and system fields
+            {utils.CYELLOW}-fields "a:b:c:..."{utils.CEND} --> print in table format the specified fields.
+            {utils.CYELLOW}-fields all{utils.CEND} --> print in table format"""
         return help
 
     #else:
@@ -88,13 +88,16 @@ def option_q(args):
     _queryAndPrint(q,fields=fields,systemFields=systemFields,nullFields=nullFields)
 
 def option_cc(args):
+    colorama.just_fix_windows_console()
+
     if '-h' in args:
         help = f"""
-        {utils.CGREEN}-cc{utils.CEND} 
-            Checks the catalogs. Gets all catalogs, does a getOffers, getOfferDetails, basketwithoutconfig and basket with config
-            {utils.CGREEN}-code{utils.CEND} - Catalogue Code. does it for a single catalog. 
-            {utils.CGREEN}-list{utils.CEND} - List all the catalogues. 
-            """ 
+        {utils.CYELLOW}-cc{utils.CEND} 
+            Checks the catalogs. Gets all catalogs, does a getOffers, getOfferDetails. Performs basketwithoutconfig and basket with config, if -basket is set. 
+            {utils.CYELLOW}-code{utils.CEND} - Catalogue Code. does it for a single catalog. 
+            {utils.CYELLOW}-list{utils.CEND} - List all the catalogues. 
+            {utils.CYELLOW}-basket{utils.CEND} - Performs basket operations. """ 
+
         return help
 
     connectionInit(args)
@@ -103,20 +106,22 @@ def option_cc(args):
    # quantity = getParam(args,'-checkCatalogs',2)
     catcatalogueCode = getParam(args,'-code')
     list = True if '-list' in args else False
+    basketOps = True if '-basket' in args else False
+
     account = getParam(args,'-account')
 
     if list == True:
         digitalCommerceUtil.printCatalogs()
         return
 
-    digitalCommerceUtil.checkOffers(catcatalogueCode=catcatalogueCode,account=account)
+    digitalCommerceUtil.checkOffers(catcatalogueCode=catcatalogueCode,account=account,basketOps=basketOps)
 
     print()
 
 def option_d(args):
     help = f"""
-        {utils.CGREEN}-d objectName{utils.CEND} --> Describe an object
-            {utils.CGREEN}-d objectName:fieldName{utils.CEND} --> describe a field in the objec"""
+        {utils.CYELLOW}-d objectName{utils.CEND} --> Describe an object
+            {utils.CYELLOW}-d objectName:fieldName{utils.CEND} --> describe a field in the object"""
     if '-h' in args:
         return help    
 
@@ -143,7 +148,7 @@ def option_d(args):
 def option_l(args):
     if '-h' in args:
         help = f"""
-        {utils.CGREEN}-l{utils.CEND} --> current org limits consuptions. """
+        {utils.CYELLOW}-l{utils.CEND} --> current org limits consuptions. """
         return help
     connectionInit(args)
     action = '/services/data/v51.0/limits'
@@ -170,10 +175,10 @@ def option_l(args):
 def option_o(args):
     if '-h' in args:
         help = f"""
-        {utils.CGREEN}-o{utils.CEND} --> List all Objects
-            {utils.CGREEN}-name objectName{utils.CEND}  --> get one row from the object
-            {utils.CGREEN}-name objectName:Id{utils.CEND} --> get the row especified by the Id
-            {utils.CGREEN}-like name{utils.CEND} --> where the Name contains the substring name"""
+        {utils.CYELLOW}-o{utils.CEND} --> List all Objects
+            {utils.CYELLOW}-name objectName{utils.CEND}  --> get one row from the object
+            {utils.CYELLOW}-name objectName:Id{utils.CEND} --> get the row especified by the Id
+            {utils.CYELLOW}-like name{utils.CEND} --> where the Name contains the substring name"""
 
         return help
         
@@ -228,10 +233,9 @@ def option_o(args):
 
 def option_default(args):
     help = f"""
-        {utils.CGREEN}-default:set key value{utils.CEND} --> defaults the specified key-value
-        {utils.CGREEN}-default:del key  {utils.CEND}  --> deletes the default
-        {utils.CGREEN}-default:get key  {utils.CEND}  --> displays the current value
-        """
+        {utils.CYELLOW}-default:set key value{utils.CEND} --> defaults the specified key-value
+        {utils.CYELLOW}-default:del key  {utils.CEND}  --> deletes the default
+        {utils.CYELLOW}-default:get key  {utils.CEND}  --> displays the current value"""
 
     if '-h' in args:
         return help   
@@ -273,19 +277,24 @@ def option_default(args):
 
 def option_logs(args):
     help = f"""
-        {utils.CGREEN}-logs{utils.CEND} --> list logs in the org. 
-            {utils.CGREEN}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K
-            {utils.CGREEN}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
-                Examples:
-                    "Id:XXXXXXXX"
-                    "name:Onboarding Site Guest User"
-                    "Alias:John.Doe"
-                    "FirstName:Onboarding"
-                    "ProfileId:00e3O000000IHneQAG"
-                {utils.CPURPLE}Defaultable loguser{utils.CEND}: Can be set to default. -default:set loguser "Alias:John.Doe"
-        {utils.CGREEN}-logs Id{utils.CEND} --> parse the logs with the provided Id
-        {utils.CGREEN}-logs -last X {utils.CEND}--> parses the last X logs. 
-        """
+        {utils.CYELLOW}-logs Id{utils.CEND} --> parse the log with the provided Id. No modifiers.
+        {utils.CYELLOW}-logs inputfile {utils.CEND}--> parses the file provided in the inputfile. {utils.CGREEN}InCli -logs -inputfile "path to file/xxxx.log"{utils.CEND} No modifiers.
+        {utils.CYELLOW}-logs store {utils.CEND}--> parses the files saved locally in order of creation(download) 
+            {utils.CYELLOW}-error {utils.CEND}--> parses the files saved locally and displays only the ones with errors. {utils.CGREEN}InCli -logs -store -error "{utils.CEND} 
+        {utils.CYELLOW}-logs -last X {utils.CEND}--> parses the last X logs. X as number.
+        {utils.CYELLOW}-logs -tail {utils.CEND}--> activelly parsers new debug logs as they are created.
+            {utils.CYELLOW}-deletelogs {utils.CEND}--> as log files are processed, they are deleted from the server. The local copy remains. 
+            {utils.CGREEN}-logs -u OrgAlias -where "LogLength>3000"  -tail -deletelogs{utils.CEND} -> parses log files of size > 3000 as they are created. Deletes the retrieved logs. 
+        {utils.CYELLOW}-logs{utils.CEND} --> lists log records in the org. 
+            {utils.CYELLOW}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K
+                {utils.CGREEN}-logs -limit 1000{utils.CEND}, displays the last 1000 log records
+            Modifiers:
+            {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
+                {utils.CGREEN}-loguser Id:0053O000000IHneQAG, -loguser "name:Onboarding Site Guest User", -loguser Alias:John.Doe, -loguser FirstName:Onboarding, -loguser ProfileId:00e3O000000IHneQAG{utils.CEND}
+                {utils.CGREEN}Defaultable loguser{utils.CEND}: Can be set to default. {utils.CGREEN}-default:set loguser "Alias:John.Doe{utils.CEND}"
+            {utils.CYELLOW}-where X {utils.CEND}--> the where clause for a query.  
+                {utils.CGREEN}InCli -logs -loguser Alias:John.Doe -where="Status<>'Success" -last 10" {utils.CEND} --> parses the last 10 logs for user John.Doe where the status is not Success
+            {utils.CYELLOW}-file {utils.CEND}--> creates 2 files for the parsed file, txt and html format.  """
 
     if '-h' in args:
         return help
@@ -296,32 +305,33 @@ def option_logs(args):
     level = getParam(args,'-level') 
     loguser = getParam(args,'-loguser') 
     whereClause = getParam(args,'-where') 
+    toFile = True if '-file' in args else False
+    inputfile = getParam(args,'-inputfile') 
+    tail = True if '-tail' in args else False
+    deletelogs = True if '-deletelogs' in args else False
+    store = True if '-store' in args else False
+    error = True if '-error' in args else False
+
 
     if loguser == None:
         loguser = restClient.getConfigVar('loguser')
 
-    if logId == None and last== None:
+    if logId == None and last== None and inputfile==None and tail == False and store==False:
         connectionInit(args)
         lim = 50 if limit == None else limit
-        id = None
-        if loguser != None:
-            chunks = loguser.split(":")
-            key = chunks[0] if len(chunks)>1 else 'Id'
-            value = chunks[1] if len(chunks)>1 else chunks[0]
-            id = query.queryField(f"Select Id from User where {key}='{value}'") if key.lower()!='id' else value
-            if id == None:
-                utils.raiseException('QUERY',f"User with field {key} = {value} does not exist in the User Object.")
-        if id != None:
-            print(f"Logs for user {loguser}, id:{id}")
-        debugLogs.printLogs(logUserId=id,limit=lim,whereClause=whereClause)
+
+        debugLogs.printLogRecords(loguser=loguser,limit=lim,whereClause=whereClause)
         return
 
-    connectionInit(args)
-    debugLogs.parseLog(logId,lastN=last,level=level,whereClause=whereClause)
+    logUserId = None
+    if inputfile == None:
+        connectionInit(args)
 
-    return
+   # debugLogs.parseLog(logId=logId,lastN=last,level=level,whereClause=whereClause,writeToFile=toFile,filepath=inputfile,tail=tail,deleteLogs=deletelogs)
+    return debugLogs.parseLog(logId=logId,filepath=inputfile,loguser=loguser,lastN=last,level=level,whereClause=whereClause,writeToFile=toFile,tail=tail,deleteLogs=deletelogs,store=store,error=error)
 
 def option_h(args):
+
     module = __import__('InCli')
 
     funcs = getmembers(sys.modules[__name__], isfunction)
@@ -332,20 +342,50 @@ def option_h(args):
             continue
 
         print(eval(f'{f}(args)'))      
+    print()
 
 def connectionInit(argsIn):
 
     userName_or_ofgAlias = getParam(argsIn,'-u') 
     restClient.init(userName_or_ofgAlias)
 
+def checkVersion():
+    try:
+        from importlib import metadata
+    except ImportError:
+        import importlib_metadata as metadata
+
+    fileversion = metadata.version("InCli")
+
+    try:
+        restClient.init('ConnectionLess')
+        res = restClient.requestRaw(url='https://pypi.org/pypi/InCli/json')
+        version = res['urls'][1]['filename'].split('-')[1].split('.tar')[0]
+        if version != fileversion:
+            print()
+            print(f"Version {fileversion}. Version {version} is available --> {utils.CGREEN}pip install InCli --upgrade{utils.CEND}")
+        else:
+            print()
+            print(f"InCli version {fileversion} ")
+    except Exception as e:
+        print(e)
+
 def _main(argsIn):
-    restClient.setLoggingLevel(logging.INFO)
+
+    if "-debug" in argsIn:
+        restClient.setLoggingLevel(level=logging.DEBUG)
+    else:
+        restClient.setLoggingLevel(logging.INFO)
+
+    restClient.glog().debug("In debug mode")
+    checkVersion()
 
     if '-h' in argsIn:
+        colorama.just_fix_windows_console()
+
         help = f"""
-    {utils.CGREEN}-u{utils.CEND} --> username or org alias to be used to log into the org. 
-            {utils.CPURPLE}Defaultable u{utils.CEND}: Can be set to a default value --> -default:set u "xx@adas.com"
-    """
+        {utils.CYELLOW}-u{utils.CEND} --> username or org alias to be used to log into the org. 
+            {utils.CGREEN}Defaultable u{utils.CEND}: Can be set to a default value --> {utils.CGREEN}InCli -default:set u "xx@adas.com {utils.CEND}"""
         print(help)
 
     funcs = getmembers(sys.modules[__name__], isfunction)
@@ -362,26 +402,30 @@ def _main(argsIn):
         ar = f"option_{ar}"
         if ar in functions:
         #       module = __import__('InCli')
-            eval(f'{ar}(args)')
+            res = None
+            res = eval(f'{ar}(args)')
+            return res
         #      func = getattr(module, ar)
         #      func(args)
 
     if '-h' in argsIn:
         print()
         print(utils.CBOLD+"SFDX Commands:"+utils.CEND)
-        print(f" - {utils.CGREEN}sfdx force:org:list --verbose --all {utils.CEND}--> to list all authorized Orgs and Connection Status")
-        print(f" - {utils.CGREEN}sfdx auth:web:login -r 'Instance Url' -a 'Alias' {utils.CEND}--> to re-authorize")
-        print(f" - {utils.CGREEN}sfdx auth:web:login -u 'userName'  -a 'alias' {utils.CEND}--> to authorize and Org")
+        print(f" - {utils.CYELLOW}sfdx force:org:list --verbose --all {utils.CEND}--> to list all authorized Orgs and Connection Status")
+        print(f" - {utils.CYELLOW}sfdx auth:web:login -r 'Instance Url' -a 'Alias' {utils.CEND}--> to re-authorize")
+        print(f" - {utils.CYELLOW}sfdx auth:web:login -u 'userName'  -a 'alias' {utils.CEND}--> to authorize and Org")
         print()
 
 def main():
     argsIn = sys.argv
+
     try:
         _main(argsIn)
 
     except Exception as e:
         utils.printException(e)
-        traceback.format_exc()
+        if "-debug" in sys.argv:
+            print(traceback.format_exc())
 
 if __name__ == '__main__':
     main()
