@@ -33,7 +33,7 @@ def checkBasketError():
       utils.raiseException(lc['response']['errorCode'],lc['response']['error'],other=lc['action'])
   if 'success' in lc['response'] and lc['response']['success'] == False:
       utils.raiseException(lc['response']['errorCode'],f"{inspect.stack()[1].function}: success:{lc['response']['success']}  isBasketValid:{lc['response']['isBasketValid']}")
-  if 'offerDetails' in lc['response']['result']:
+  if 'result' in lc['response'] and 'offerDetails' in lc['response']['result']:
       utils.raiseException(f"CreateBasket {lc['response']['result']['offerDetails']['StatusCode']}",lc['response']['result']['offerDetails']['messages'][0])
 
   #if lc['response']['result']['error'] !='OK':
@@ -155,7 +155,7 @@ def createBasketAfterConfig(catalogcode,offerDetails,contextKey=None,context=Non
     "productConfig": getResult(offerDetails)
   }
 
-  restClient.writeFile('body12xx',body)
+ # restClient.writeFile('body12xx',body)
   response = restClient.callAPI(action, method="post", data=body)
   checkBasketError()
 
