@@ -58,7 +58,7 @@ def printCatalogs(catcatalogueCode=None):
     print() 
     return catalogs
 
-def checkOffers(path=None,quantity=None,catcatalogueCode=None,account=None):
+def checkOffers(path=None,quantity=None,catcatalogueCode=None,account=None,basketOps=False):
 
     catalogs = printCatalogs(catcatalogueCode)
 
@@ -78,7 +78,7 @@ def checkOffers(path=None,quantity=None,catcatalogueCode=None,account=None):
                 'Error':'',
                 "__color__":utils.CEND
             }
-            offers = digitalCommerce.getOfferByCatalogue(catalog['vlocity_cmt__CatalogCode__c'])
+            offers = digitalCommerce.getOfferByCatalogue(catalog['vlocity_cmt__CatalogCode__c'],pagesize=400)
             times['elapsed'] = restClient.getLastCallTime()
             l = len(offers) if offers is not None else 0
             numOffersList.append(l)
@@ -177,10 +177,16 @@ def checkOffers(path=None,quantity=None,catcatalogueCode=None,account=None):
     print()
     print()
 
-    print(utils.CLIGHT_CYAN+f"Getting offerDetails, createBasket, createBasket with config per offer. total offers {totalOffers}"+utils.CEND)
+    if basketOps == True:
+        print(utils.CLIGHT_CYAN+f"Getting offerDetails, createBasket, createBasket with config per offer. total offers {totalOffers}"+utils.CEND)
+    else:        
+        print(utils.CLIGHT_CYAN+f"Getting offerDetails. total offers {totalOffers}"+utils.CEND)
+
 
     offersList = []
 
+    accountId = None
+
     if account != None:
         chunks = account.split(':')
         id = query.queryField(f" select Id from Account where {chunks[0]} = '{chunks[1]}'")
@@ -193,19 +199,23 @@ def checkOffers(path=None,quantity=None,catcatalogueCode=None,account=None):
         for offerCount,offer in enumerate(catOffers['offers']):
             _offer = {
                 'catalogCode':catOffers['catCode'],
-                'offerCode':digitalCommerce.getOfferCode(offer)
+                'offerCode':digitalCommerce.getOfferCode(offer),
+                'basketOps':basketOps
             }
             if accountId != None:
                 _offer['accountId']=id
             offersList.append(_offer)
 
-    thread.processList(dba,offersList,1)
+    thread.processList(dba,offersList,10)
     newlist = sorted(_theTimes, key=lambda d: f"{d['catalog']}{d['offerCode']}")
     utils.printFormated(newlist)
+    for error in _errors:
+        utils.printException(error)
 
     print()
 
 _theTimes = []
+_errors = []
 def dba(offerCodes):
     try:
         offerCode = offerCodes['offerCode']
@@ -215,25 +225,31 @@ def dba(offerCodes):
             'offerCode':offerCode,
             'details':'',
             'createBasket':'',
-            'basket contextKey':'',
             'afterConfig':'',
             '__color__':utils.CEND,
             "error":''
         }
 
-        if offerCode == 'PROMO_NOS_OFFER_007':
-            print()
         details = digitalCommerce.getOfferDetails(catalogCode,offerCode)
         times['details'] = restClient.getLastCallTime()
 
-        basket = digitalCommerce.createBasket(catalogCode,offerCode)
-        times['createBasket'] = restClient.getLastCallTime()
-        times['basket contextKey']=basket['cartContextKey']
+        if offerCodes['basketOps'] == True:
+            basket = digitalCommerce.createBasket(catalogCode,offerCode)
+            times['createBasket'] = restClient.getLastCallTime()
 
-        offerDetails = updateOfferField(details,'0001','Quantity',4,'lineNumber')
+            if details['result']['offerDetails']['offer']['offerType'] == 'Promotion':
+                try:
+                    offerDetails = updateOfferField(details,'ATT_NOS_OTT_SUBSCRIPTION_ID','values','xxxxxx','code')
+                except Exception as e:
+                    if e.args[0] == 'Object does not contain element by path ATT_NOS_OTT_SUBSCRIPTION_ID':
+                        offerDetails = updateOfferField(details,'ATT_NOS_PRICE_CONDITIONS','values','PRICE_COND_003','code')
+                    else:
+                        raise
+            else:
+                offerDetails = updateOfferField(details,'0001','Quantity',4,'lineNumber')
 
-        basket2 = digitalCommerce.createBasketAfterConfig(catalogCode,offerDetails)
-        times['afterConfig'] = restClient.getLastCallTime()
+            basket2 = digitalCommerce.createBasketAfterConfig(catalogCode,offerDetails)
+            times['afterConfig'] = restClient.getLastCallTime()
         if 'accountId' in offerCodes and 1==2:
             times['cart']=''
             cart = digitalCommerce.createCart(offerCodes['accountId'],catalogCode,basket2['cartContextKey'],createAsset=False)
@@ -246,8 +262,14 @@ def dba(offerCodes):
             print()
 
     except Exception as e:
-        times['error']=e.args[0]['error']
-        times['__color__'] = utils.CRED
+        if len(e.args)> 0  and 'error' in e.args[0]:
+            times['error']=e.args[0]['errorCode']
+        else:
+            times['error']=f"{e}"
+
+        _errors.append(e)
+
+        times['__color__'] = utils.CLIGHT_RED
 
     _theTimes.append(times)
 
