@@ -19,7 +19,7 @@ def _threadContext(setConnectionName=None):
     if id not in _allThreadsContext:
         _currentConnectionName = setConnectionName if setConnectionName != None else _currentConnectionName
         if _currentConnectionName == None:
-            utils.raiseException('ConnectionError',"No default connection for thread")
+            utils.raiseException('ConnectionError',"Current Connection is no set.")
         th = {
             'connectionName': _currentConnectionName,
             'calls':[]
@@ -73,13 +73,12 @@ def getConfigOrgsNames():
 
 ##################################################################
 
-def glog():
-    return logging.getLogger('root')
+
 #/Users/uormaechea/Documents/Dev/python/Industries/input/ConnectionsParams.json
 _configData = None
 _configDataName = None
-def setLoggingLevel(loggingLevel=logging.INFO):
-    glog().level = loggingLevel
+#def setLoggingLevel(loggingLevel=logging.INFO):
+#    glog().level = loggingLevel
 
 def loadConfigData():
     global _configData,_configDataName
@@ -165,10 +164,14 @@ def deleteOrg_inConfigFile(orgName):
     jsonFile.write(_configDataName,cd)
     loadConfigData()
 
+loggerName = 'restClient'
+def glog():
+    return logging.getLogger(loggerName)
 def setLoggingLevel(level=logging.INFO):
-    log = logging.getLogger('root')
+    log = logging.getLogger(loggerName)
     logging.basicConfig()
     log.setLevel(level)
+    pass
 
 def setConfigFile(configFile):
     """
@@ -185,6 +188,9 @@ def setConfigFile(configFile):
 sfdx_lock = threading.Lock()
 ####CONECTION
 def init(userName_or_orgAlias,connectionName=None):
+    if userName_or_orgAlias == 'ConnectionLess':
+        _initMain(userName_or_orgAlias,None)
+        return
     with sfdx_lock:
         inConf = False
         if userName_or_orgAlias == None:
@@ -198,7 +204,9 @@ def init(userName_or_orgAlias,connectionName=None):
             return
 
         try:
-            success,outputs = utils.executeCommandParse(["sfdx","force:org:display","-u", userName_or_orgAlias])
+            success,obj,outputs = utils.execute_force_org_display(userName_or_orgAlias)
+
+     #       success,outputs = utils.executeCommandParse(["sfdx","force:org:display","-u", userName_or_orgAlias])
 
         except Exception as e:
             if e.strerror == 'No such file or directory':
@@ -214,9 +222,9 @@ def init(userName_or_orgAlias,connectionName=None):
             else:
                 utils.raiseException('SFDX Error',error,other='')
 
-        obj  = {}
-        for output in outputs:
-            obj[output['KEY']] = output['VALUE']
+     #  obj  = {}
+     #   for output in outputs:
+     #       obj[output['KEY']] = output['VALUE']
 
         if obj['Connected Status'] != 'Connected':
             utils.raiseException("ConnectionStatus",f"Connected Status for client Id {userName_or_orgAlias} is {obj['Connected Status']}",other=f"Execute the following command to refresh the token.  -")
@@ -225,7 +233,7 @@ def init(userName_or_orgAlias,connectionName=None):
         assert(obj['Instance Url']!=None)
         assert(obj['Access Token']!=None)
 
-        _initMain(connectionName,obj['Instance Url'],obj['Access Token'])
+        _initMain(connectionName,obj['Instance Url'],obj['Access Token'],username= obj['Username'])
 
 def initWithToken(name,url,token=None,input=None,output=None,debug=None):
     _initMain(name,url,token,input,output,debug)
@@ -274,7 +282,7 @@ def _checkAndSetConnectionIfExists(connectionName):
             return True
     return False
 
-def _initMain(name,url,token=None,input=None,output=None,debug=None):
+def _initMain(name,url,token=None,input=None,output=None,debug=None,username=None):
     if _checkAndSetConnectionIfExists(name):
         return
 
@@ -293,6 +301,8 @@ def _initMain(name,url,token=None,input=None,output=None,debug=None):
 
         'nameSpace':'vlocity_cmt'
     }
+    if username != None:
+        connection['username'] = username
     _initializedConnections.append(connection)
     _threadContext(connection['connectionName'])
 
@@ -322,7 +332,15 @@ def debugFolder():
 def logFolder():
     return _gerFolder('log')
 def _gerFolder(name):
-    folder =  getCurrentThreadConnection()[name]
+    try:
+        folder =  getCurrentThreadConnection()[name]
+    except Exception as e:
+        if e.args[0]['error'] == 'No default connection for thread':
+            loadConfigData()
+            folder = _configData['folders'][name]
+        else:
+            raise
+
     if folder[-1] != '/':
         folder = folder + '/'
     if file.exists(folder) == False:
@@ -392,8 +410,9 @@ def requestRaw(url,action=None,method = 'get',parameters = {},data={},headers={}
         'callTime':datetime.datetime.now()
     }
 
-    glog().debug(f"Current Connection {_currentConnectionName}")
-    _pushThreadCall(call)
+    if _currentConnectionName != 'ConnectionLess':
+        glog().debug(f"Current Connection {_currentConnectionName}")
+        _pushThreadCall(call)
 
     r = None
 
@@ -444,10 +463,11 @@ def requestRaw(url,action=None,method = 'get',parameters = {},data={},headers={}
                     call['response'] = r.text
                 
         else:
-            glog().warn('API error when calling %s : %s' % (r.url, r.content))
+          #  glog().warn('API error when calling %s : %s' % (r.url, r.content))
             call['response'] = call['error']
 
-    _updateThreadCall(call)
+    if _currentConnectionName != 'ConnectionLess':
+        _updateThreadCall(call)
 
     return call['response']
 
