@@ -1,8 +1,6 @@
 from datetime import datetime
 from logging import log
 import logging
-from symbol import del_stmt
-from turtle import width
 from . import objectUtil
 import inspect,simplejson
 import os,sys
@@ -61,9 +59,36 @@ def stringifyUrlParameters(parameters,exclude,initSeparator='?'):
   return ret
 
 def executeCommand(command):
-    list_files = subprocess.run(command,capture_output=True,text=True)
+    is_windows = sys.platform.startswith('win')
+    if is_windows == True:
+        list_files = subprocess.run(command,capture_output=True,text=True,shell=True)
+    else:
+        list_files = subprocess.run(command,capture_output=True,text=True)
+
     return list_files
 
+def execute_force_org_display(userName_or_orgAlias):
+    def getValue(field):
+        if field in line:
+            chunks = line.split(field)
+            val = chunks[1].strip()
+            obj[field]=val
+    output = executeCommand(["sfdx","force:org:display","-u", userName_or_orgAlias])
+    if output.stdout == '':
+        return False,None,output
+
+    lines = output.stdout.splitlines()
+
+    obj = {}
+    for line in lines:
+        getValue('Access Token')
+        getValue('Connected Status')
+        getValue('Instance Url')
+        getValue('Username')
+
+
+    return True,obj,output
+
 def executeCommandParse(command):
     output = executeCommand(command)
 
@@ -454,17 +479,20 @@ def repeatingSequence(objs,field):
     repeatingSequences = []
     lastX = 0
     for x,val in enumerate(objs):
-        if x < lastX:
+        if x <= lastX:
             continue
         firstdelta = None
         lastDelta = 0
         positions = []
+        objx = objs[x]['output']
+        if objs[x][field]=='OrderItem CancelWF --> false':
+            print(x)
 
         for y in range(x+1,len(objs)):
+            objy=objs[y]['output']
 
             if field not in objs[y]:
                 _o = objs[y]
-                print()
             if objs[y][field] == objs[x][field]:
                 line = objs[y][field]
                 if firstdelta == None:
@@ -479,6 +507,8 @@ def repeatingSequence(objs,field):
                         if y+z >= len(objs):
                             seq=False
                             break
+                        objz=objs[y+z]['output']
+
                         if objs[y+z][field] != objs[x+z][field]:
                             seq = False
                             break
@@ -489,7 +519,7 @@ def repeatingSequence(objs,field):
                 else:
                     break
                 if seq == True:
-                    lastX = y
+                    lastX = y 
 
         if len(positions) > 0:
             repeatingSequences.append(positions)
